@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 import sys
+import re
 import semver
 
 from halo import Halo
@@ -22,6 +23,7 @@ logger = Logger()
 
 def entrypoint(project, timeout):
 
+    commits = []
     lock = CaptainHook()
     if timeout:
         lock.set_timeout(timeout)
@@ -59,7 +61,6 @@ def entrypoint(project, timeout):
             ],
         )
 
-        manage_youtrack_card(project, commits, new_version)
     else:
         # Se non viene trovata la release e non ci sono tag, viene saltato il check delle migrations e l'update delle card su youtrack
         logger.warning("Nessun tag trovato, sto per pubblicare il tag 0.1.0")
@@ -69,6 +70,7 @@ def entrypoint(project, timeout):
         message = f"First release with tag {new_version}"
 
     create_release(repo, new_version, message, project)
+    manage_youtrack_card(project, commits, new_version)
 
 
 def get_release(repo, tag):
@@ -160,3 +162,33 @@ def manage_youtrack_card(project, commits, new_version):
                 logger.warning(
                     f"Si è verificato un errore durante lo spostamento della card {issue_id} in {release_state}"
                 )
+            repos_status = get_repos_status_from_issue(issue_id)
+            if all(r["deployed"] for r in repos_status.values()):
+                try:
+                    youtrack.update_deployed_field(issue_id)
+                    logger.info("Custom field Deployed aggiornato su YouTrack")
+                except Exception:
+                    logger.warning(
+                        "Si è verificato un errore durante l'aggiornamento del custom field Deployed"
+                    )
+
+
+def get_repos_status_from_issue(issue_id):
+    regex_pr = r"^PR .* -> https:\/\/github\.com\/primait\/(.*)\/pull\/([0-9]*)$"
+    regex_deploy = r"^Deploy in produzione di (.*) effettuato con la release"
+    comments = youtrack.get_comments(issue_id)
+    repos_status = {}
+
+    for c in comments:
+        m = re.match(regex_pr, c["text"])
+        if m:
+            project = m.group(1)
+            pr_number = int(m.group(2))
+            repos_status[project] = {}
+            repos_status[project]["pr"] = pr_number
+            repos_status[project]["deployed"] = False
+        m = re.match(regex_deploy, c["text"])
+        if m:
+            project = m.group(1)
+            repos_status[project]["deployed"] = True
+    return repos_status
