@@ -303,8 +303,7 @@ def get_last_tag_number(tags):
     for tag in tags:
         if is_semver(tag.name):
             return tag.name
-    logger.warning("Nessun tag trovato, sto per pubblicare tag 0.1.0")
-    return "0.1.0"
+    return None
 
 
 def is_semver(tag):
