@@ -79,3 +79,6 @@ class GithubHandler(metaclass=Singleton):
 
     def get_build_status(self, repo, ref):
         return self.get_repo(repo).get_commit(ref).get_combined_status()
+
+    def get_releases(self, repo):
+        return self.get_repo(repo).get_releases()
