@@ -32,6 +32,12 @@ class YoutrackHandler(metaclass=Singleton):
     def get_issue(self, issue_id):
         return self._client.get_issue(issue_id)
 
+    def get_comments(self, issue_id):
+        return self._client.get_comments(issue_id)
+
+    def update_deployed_field(self, issue_id):
+        return self._client.execute_command(issue_id, "Deployed Today")
+
     def validate_issue(self, issue_id):
         try:
             if self.get_issue(issue_id):
